@@ -16,6 +16,7 @@ class ONTSwapStatus(enum.Enum):
     started = 'started'
     success = 'success'
     failed = 'failed'
+    cancelled = 'cancelled'
 
 
 class ONT(Base):
@@ -119,6 +120,9 @@ class ONTSWAP(Base):
     task_finish_datetime = Column(DateTime)
     notification_sent_type = Column(String(length=24))
     notification_sent_datetime = Column(DateTime)
+    cancel_reason = Column(String(length=256))
+    cancelled_by = Column(String(length=256), comment='user who cancelled the swap')
+    cancelled_at = Column(DateTime)
     error = Column(String(length=256))
 
     def __repr__(self):
